#include	<stdio.h>
/*
input: file input.txt
first line: N K, N-number of states, K-size of alphabet
second line: N numbers, 0 - nonterminal state, 1 - terminal
N more lines: K numbers, Transition from this state by symbol k
last line: sequence of numbers to check

output: file output.txt
contains minimal automata in same format as in input
and word Accepted or Rejected - answer

Example:
input.txt
4 1
1 0 1 0
1
2
3
0
1 1 1
//it Accepts sequences length of 2*t
output.txt
2 1
1 0
1
0
Rejected
*/


FILE *in, *out;

const int MN = 1000;//max number of states
const int MK = 100;//max size of alphabet

int N, K;//States:0..N-1, alphabet: 0..K-1
bool F[MN];//isTerminal
int T[MN][MK];//Transitions

//the same for compressed automata
int newN, newK;
bool newF[MN];
int newT[MN][MK];

//some variables
bool used[MN];
int oldName[MN];
int newName[MN];
int A[MN][MN];
int S[MN], R[MN], RR[MN];
int cntR, cntRR;
int cntMeet;

void meet()
{
	++cntMeet;
	cntRR = 0;
	int i;
	for (i = 0; i < N; ++i)
		if (A[S[i]][R[i]])
			RR[i] = A[S[i]][R[i]] - 1;
		else
		{
			RR[i] = (A[S[i]][R[i]] = i + 1) - 1;
			++cntRR;
		}
	for (i = 0; i < N; ++i)
		A[S[i]][R[i]] = 0;
}

void solve()
{
	int i;
	for (i = 0; i < N; ++i)
		R[i] = F[i];
	cntR = 2;
	cntMeet = 0;
	bool changed = true;
	while (changed)
	{
		changed = false;
		for (int k = 0; k < K; ++k)
		{
			for (i = 0; i < N; ++i)
				S[i] = R[T[i][k]];
			meet();
			if (cntRR != cntR)
			{
				cntR = cntRR;
				changed = true;
				for (i = 0; i < N; ++i)
					R[i] = RR[i];
			}
		}
	}
	newN = 0;
	newK = K;
	for (i = 0; i < N; ++i)
		if (!used[R[i]])
		{
			used[R[i]] = true;
			newF[newN] = F[i];
			newName[R[i]] = newN;
			oldName[newN++] = i;
		}
	for (i = 0; i < newN; ++i)
		for (int j = 0; j < K; ++j)
			newT[i][j] = newName[R[T[oldName[i]][j]]];
	fprintf(out, "%d %d\n", newN, newK);
	for (i = 0; i < newN; ++i)
		fprintf(out, "%d ", (int)newF[i]);
	fprintf(out, "\n");
	for (i = 0; i < newN; ++i)
	{
		for (int j = 0; j < K; ++j)
			fprintf(out, "%d ", newT[i][j]);
		fprintf(out, "\n");
	}
	int state = 0;
	while (fscanf(in, "%d", &i) == 1)
		state = newT[state][i];
	if (newF[state])
		fprintf(out, "Accepted\n");
	else
		fprintf(out, "Rejected\n");
}

int main()
{
	in = fopen("input.txt", "r");
	out = fopen("output.txt", "w");
	fscanf(in, "%d%d", &N, &K);
	int i, j;
	for (i = 0; i < N; ++i)
	{
		int t;
		fscanf(in, "%d", &t);
		F[i] = t == 1;
	}
	for (i = 0; i < N; ++i)
		for (j = 0; j < K; ++j)
			fscanf(in, "%d", &T[i][j]);
	solve();
	fclose(in);
	fclose(out);
	return 0;
}
